"""Common configuration constants
"""

PROJECTNAME = "mailtoplone.base"

ADD_PERMISSIONS = { 
	# -*- extra stuff goes here -*-

   "InBox"  :  "mailtoplone.base: Add InBox",

   "Email"  :  "mailtoplone.base: Add Email",
	}
